@@ -1,10 +1,11 @@
+use std::collections::HashMap;
+use std::marker::PhantomData;
+use std::sync::{Arc, RwLock};
+
 use crate::errors::Error;
 use crate::log::{SchemaEvent, Writer};
 use crate::transaction::TransactionTable;
 use crate::{Key, Value};
-use std::collections::HashMap;
-use std::marker::PhantomData;
-use std::sync::{Arc, RwLock};
 
 #[derive(Clone, Debug)]
 pub struct Table<K, V, Log>
@@ -49,6 +50,11 @@ where
         Ok(val)
     }
 
+    pub fn get_all(&self) -> Result<HashMap<K, V>, Error> {
+        let val = self.data.read().map_err(Error::lock_error)?.clone();
+        Ok(val)
+    }
+
     pub fn insert(&self, key: K, val: V) -> Result<Option<V>, Error> {
         let prior = self
             .data
